package com.muyu.rule.service.impl;

import cn.hutool.core.util.DesensitizedUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.enums.SysRuleYesNo;
import com.muyu.common.core.exception.ServiceException;
import com.muyu.rule.mapper.RuleEditionMapper;
import com.muyu.rule.service.RuleEditionService;
import com.muyu.rule.service.RuleService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import rule.data.engine.GenerateConstant;
import rule.domain.Rule;
import rule.domain.RuleEdition;

/**
 * @ClassName RuleEditionServiceImpl
 * @Description 描述
 * @Author Chen
 * @Date 2024/8/25 09:42
 */
@Service
public class RuleEditionServiceImpl extends ServiceImpl<RuleEditionMapper, RuleEdition> implements RuleEditionService {
    @Autowired
    private RuleServiceImpl ruleServiceImpl;
//    @Autowired
//    private RuleService ruleService;;

    /**
     * 禁用规则版本
     *
     * @param id
     */
    @Override
    public void disable(Long id) {
        this.settingStatus(id, SysRuleYesNo.NO.getCode());
    }


    /**
     * 启用规则版本
     *
     * @param id
     */
    @Override
    public void enable(Long id) {
        this.settingStatus(id, SysRuleYesNo.YES.getCode());
    }

    /**
     * 生成规则版本类
     *
     * @param ruleEdition
     * @return
     */
    @Override
    public RuleEdition generate(RuleEdition ruleEdition) {
        Rule rule = ruleServiceImpl.getById(ruleEdition.getRuleId());
        ruleEdition.setRuleKind(rule.getName() + "_" + ruleEdition.getRuleCoding());
        ruleEdition.setRuleEngine(GenerateConstant.generateConstant(ruleEdition));
//        LambdaQueryWrapper<RuleEdition> queryWrapper = new LambdaQueryWrapper<>();
//        queryWrapper.eq(RuleEdition::getRuleKind, ruleEdition.getRuleKind());
//
//        long count = ruleService.count(queryWrapper);
//        if (count > 0) {
//            throw new ServiceException("版本类名称重复");
//        }
        return ruleEdition;
    }


    /**
     * 通过id设置
     *
     * @param id
     * @param ruleActivate
     */
    private void settingStatus(Long id, String ruleActivate) {
        LambdaQueryWrapper<RuleEdition> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(RuleEdition::getId, id);
        boolean exists = this.exists(queryWrapper);
        if (!exists) {
            throw new ServiceException("不存在");
        }
        if (!SysRuleYesNo.isCode(ruleActivate)) {
            throw new ServiceException("设置违法");
//            DesensitizedUtil.desensitized()
        }
// hutool       desensitization

        LambdaUpdateWrapper<RuleEdition> updateWrapper = new LambdaUpdateWrapper<>();
        updateWrapper.eq(RuleEdition::getId, id);
        updateWrapper.set(RuleEdition::getRuleActivate, ruleActivate);
        this.update(updateWrapper);
    }
}
